import 'package:awesome_loader_null_safety/src/Dot.dart';
import 'package:flutter/material.dart';

class Loader3 extends StatefulWidget {
  final Color? color;

  const Loader3({Key? key, this.color}) : super(key: key);

  @override
  _Loader3State createState() => _Loader3State();
}

class _Loader3State extends State<Loader3> with SingleTickerProviderStateMixin {
  late AnimationController _controller;
  late Animation<double> _animationRotation;
  late Animation<double> _animationRadiousOut;
  late Animation<double> _animationRadiousIn;
  final double _initialRadious = 20.0;
  double _radious = 20.0;

  @override
  void initState() {
    super.initState();

    _controller =
        AnimationController(vsync: this, duration: Duration(seconds: 2));

    _animationRadiousIn = Tween<double>(begin: 1.0, end: 0.5).animate(
        CurvedAnimation(
            parent: _controller,
            curve: Interval(0.0, 0.5, curve: Curves.linear)));

    _animationRadiousOut = Tween<double>(begin: 0.5, end: 1.0).animate(
        CurvedAnimation(
            parent: _controller,
            curve: Interval(0.5, 1.0, curve: Curves.linear)));

    _animationRotation = Tween<double>(begin: 0.0, end: 1.0).animate(
        CurvedAnimation(
            parent: _controller,
            curve: Interval(0.0, 1.0, curve: Curves.linear)));

    _controller.addListener(() {
      setState(() {
        if (_controller.value >= 0.0 && _controller.value <= 0.5) {
          _radious = _initialRadious * _animationRadiousIn.value;
        } else if (_controller.value >= 0.5 && _controller.value <= 1.0) {
          _radious = _initialRadious * _animationRadiousOut.value;
        }
      });
    });

    _controller.repeat();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        child: Center(
            child: RotationTransition(
      turns: _animationRotation,
      child: Container(
        width: 50.0,
        height: 50.0,
        child: Stack(
          children: <Widget>[
            Transform.translate(
              offset: Offset(0, _radious),
              child: Dot(
                radious: 10.0,
                color: widget.color,
              ),
            ),
            Transform.translate(
              offset: Offset(_radious, 0),
              child: Dot(
                radious: 10.0,
                color: widget.color,
              ),
            ),
            Transform.translate(
              offset: Offset(-_radious, 0),
              child: Dot(
                radious: 10.0,
                color: widget.color,
              ),
            ),
            Transform.translate(
              offset: Offset(0, -_radious),
              child: Dot(
                radious: 10.0,
                color: widget.color,
              ),
            ),
          ],
        ),
      ),
    )));
  }
}
